#Example Code for the analysis of plasma-proteins on common cancers
library(TwoSampleMR) # version 0.5.6
library(readxl) # version 1.4.1
library(gridExtra) # version 2.3 
library(forestplot) # version 3.1.1
library(scales) # version 1.2.1
library(tidyverse) # version 1.3.1
library(writexl) # version 1.4.2
library(phenoscanner) # version???
library(RVAideMemoire) # version 0.9-81-2
library(coloc) # version 5.1.0
library(rstatix) # version 0.7.1
library(locuscomparer) # version 1.0.0

# loading pqtl data ---------------------------------------------------
#' @source pubmed.ncbi.nlm.nih.gov/32895551/
pqtl_plasma <- read_excel("genetic_instrument_exposure_plasma_protein.xlsx")

# Outcome MS --------------------------------------------------------------
#' @source https://gwas.mrcieu.ac.uk/datasets/
snp_MS <- extract_outcome_data(
  snps = unique(c(pqtl_plasma$SNP)),
  outcomes = "ebi-a-GCST006085")

harmonised_plasma_MS <- harmonise_data(pqtl_plasma, snp_MS)

# Main analysis ----------------------------------------------------------------
mr_modified <- function(dat = harmonised_csf_MS, prop_var_explained = T)
{
  mr_res <- mr(dat)
  
  pve <- dat %>% 
    dplyr::select(id.exposure, beta.exposure, se.exposure, samplesize.exposure) %>% 
    dplyr::group_by(id.exposure) %>% 
    dplyr::summarise(pve = sum((beta.exposure^2)/(beta.exposure^2 + samplesize.exposure*se.exposure^2)))
  
  if(prop_var_explained)
  {
    mr_res <- mr_res %>% 
      dplyr::left_join(pve, by = "id.exposure")
  }
  
  return(mr_res)
}


mr_plasma_MS <- mr_modified(harmonised_plasma_MS, prop_var_explained = T) %>% 
  filter(method %in% c("Wald ratio","Inverse variance weighted"))

# Table S4: Heterogeneity test --------------------------------------------
mr_heterogeneity(harmonised_plasma_MS)
mr_pleiotropy_test(harmonised_plasma_MS)

# Table 1 -----------------------------------------------------------------
table1_plasma <- mr_plasma_MS %>% 
  filter(pval < 0.05/732) %>% 
  left_join(pqtl_plasma, by = "exposure")


table1 <- bind_rows(table1_plasma) %>% 
  generate_odds_ratios() %>% 
  mutate(`OR (95% CI)` = sprintf("%.2f (%.2f, %.2f)", or, or_lci95, or_uci95),
         `P value` = scales::scientific(pval),
         `PVE` = paste0(sprintf("%.2f", 100*pve), "%"),
         `F statistics` = sprintf("%.2f", F_statistics)) %>% 
  dplyr::select(Tissue, Protein = exposure, `UniProt ID` = UniProt,
                SNP, `Effect allele` = effect_allele.exposure, 
                `OR (95% CI)`, `P value`, 
                PVE, `F statistics`, Author)

write.csv(mr_plasma_MS, file="mr_plasma_MS.csv")
write.csv(table1_plasma, file="table1_plasma.csv")
write.csv(table1, file="table1.csv")

# Figure 1: Flowchart ----------------------------------------------------------
# Made manually by Figdraw (www.figdraw.com)

# Figure 2: Main MR Findings ---------------------------------------------------
#' @description A function to create volcano plot
volcano_plot <- function(.data, 
                         number_comparasion = 1,
                         title = "(A)",
                         col_beta = "b",
                         col_size = "pve",
                         col_label = "exposure",
                         legend.position = "none")
{
  p_thershold <- 0.05/number_comparasion
  
  message("The function is written by Authors")
  
  p <- .data %>% 
    rename(beta := !!col_beta,
           size := !!col_size,
           label := !!col_label) %>% 
    mutate(x = beta,
           y = -log10(pval),
           label = ifelse(pval < p_thershold, label, NA)) %>% 
    ggplot(aes(x = x, y = y)) +
    geom_point(aes(size = size), alpha = 0.5, color = "#000080") +
    geom_vline(xintercept = 0, linetype = 2)+
    geom_hline(yintercept = -log10(p_thershold), linetype = 2) +
    theme_classic() +
    theme(panel.grid = element_blank(),
          legend.title = element_text(size = 6.5),
          legend.text = element_text(size = 6.5),
          legend.position = legend.position)+
    labs(x = "ln(OR)", 
         y = parse(text = "-log[10]*(italic(P)-value)"),
         title = title) +
    scale_size(name = "PVE",
               breaks = c(0.2*1:3)) +
    ggrepel::geom_label_repel(aes(label = label),size = 3)
  plot(p)
}


gridExtra::grid.arrange(
  volcano_plot(mr_plasma_MS,
               number_comparasion = 732,
               legend.position = c(0.9,0.7),
               title = "Proteins"),
  ncol = 1,
  nrow = 1)

# Figure 4: External validation -----------------------------------------------------
#' @description A function to bind rows from multiple data sets contain several same columns
combine_instruments <- function(...)
{
  dat_all <- list(...)
  for (i in 1:length(dat_all)) {
    if(i == 1) name_keep <- names(dat_all[[i]])
    else name_keep <- intersect(name_keep, names(dat_all[[i]]))
  }
  
  for (i in 1:length(dat_all)) {
    dat_all[[i]] <- dplyr::select(dat_all[[i]], all_of(name_keep))
  }
  
  do.call(rbind, dat_all)
}

# select instruments used in main analysis
ext_pqtl_csf_plasma <- combine_instruments(pqtl_plasma) %>% 
  filter(SNP %in% table1$SNP)
ext_pqtl_plasma_decode_fenland <- read_excel("genetic_instrument_exposure_external_protein.xlsx")
ext_pqtl_csf_plasma <- combine_instruments(ext_pqtl_csf_plasma,
                                           ext_pqtl_plasma_decode_fenland)
ext_snp_MS_finn <- extract_outcome_data(snps = c(ext_pqtl_csf_plasma$SNP),
                                        outcomes = "ieu-b-4809",
                                        proxies = F)
ext_snp_MS <- combine_instruments(ext_snp_MS_finn)

ext_harmonised_protein_MS <- 
  harmonise_data(ext_pqtl_csf_plasma, ext_snp_MS)

ext_mr_protein_MS <- mr(ext_harmonised_protein_MS)
OR <- bind_rows(ext_mr_protein_MS) %>% 
  generate_odds_ratios() %>% 
  mutate(`OR (95% CI)` = sprintf("%.2f (%.2f, %.2f)", or, or_lci95, or_uci95))
write.csv(OR, file = "External validation.csv")


# Table S2: Phenoscanner ---------------------------------------------------

mr_phenoscanner <- function(dat, 
                            catalog = c("GWAS", "eQTL", "pQTL", "mQTL", "methQTL"),
                            pvalue = 5e-08,
                            proxies = "EUR", 
                            r2 = 0.8,
                            build = 37)
{
  stopifnot("SNP" %in% names(dat))
  
  snpquery <- unique(dat$SNP)
  query_limit <- ceiling(0.01*length(snpquery))
  
  query_res <- list()
  for (i in 1:query_limit) {
    lo_i <- 100*i - 99
    up_i <- min(100*i,length(snpquery))
    snp_i <- snpquery[lo_i:up_i]
    print(paste0("Searching for ", snp_i))
    
    for (catalogue in catalog) {
      query_i <- try(
        phenoscanner::phenoscanner(
          snpquery = snp_i, catalogue = catalogue,
          proxies = proxies, pvalue = pvalue, r2 = r2, build = build)
      )
      if(!"try-error" %in% class(query_i))
      {
        if("results" %in% names(query_i))
        {
          query_i <- list(query_i$results)
          names(query_i) <- catalogue
          query_res <- append(query_res, query_i)
        }
      }
    }
  }
  
  return(query_res)
}

pleio_pheno <- mr_phenoscanner(table1) # the key information is the SNP column
view(pleio_pheno$pQTL)
# saveRDS(pleio_pheno, file = "phenoscanner_res.rds")
# pleio_pheno <- readRDS("phenoscanner_res.rds")

pleio_pheno_summary_raw <- pleio_pheno$GWAS %>% 
  mutate(catalog = "GWAS") %>% 
  bind_rows(pleio_pheno$pQTL%>% 
              mutate(catalog = "pQTL")) %>% 
  bind_rows(pleio_pheno$mQTL%>% 
              mutate(catalog = "mQTL")) %>% 
  filter(p != "NA",
         ancestry %in% c("Mixed", "European")) %>% 
  left_join(table1_plasma %>% 
              bind_rows(table1_plasma) %>% 
              dplyr::select(exposure, Tissue:eaf.exposure) %>% 
              rename(snp = SNP),
            by = "snp") %>% 
  mutate(across(p, as.numeric)) %>% 
  group_by(trait, pmid) %>% 
  filter(p == min(p)) %>% 
  ungroup() %>% 
  dplyr::select(trait, Tissue,Protein = exposure, UniProt, snp, ref_a1, ref_a2, effect_allele.exposure:eaf.exposure, proxy, r2, rsid, a1, a2, pmid:p,catalog) %>% 
  mutate(ref_a1f = ifelse(ref_a1 == effect_allele.exposure, eaf.exposure, 1- eaf.exposure),
         ref_a1f_reliability = ifelse((ref_a1 == effect_allele.exposure&ref_a2 == other_allele.exposure)|
                                        (ref_a2 == effect_allele.exposure&ref_a1 == other_allele.exposure),
                                      "high", "low")) %>% 
  dplyr::select(trait, Tissue,Protein, UniProt, snp, effect_allele.exposure,ref_a1, ref_a2, ref_a1f,ref_a1f_reliability, proxy, r2, rsid, a1, a2, pmid:p,catalog) %>% 
  rename(effector = effect_allele.exposure,
         SNP = rsid,
         effect_allele = a1,
         other_allele = a2) %>% 
  unique() %>% 
  rename(proxy_SNP = SNP,
         SNP = snp,
         pval = p) %>% 
  mutate(effect_allele = effector,
         proxy_effect_allele = ifelse(effector == ref_a1, effect_allele, other_allele),
         beta = as.numeric(beta),
         se = as.numeric(se),
         beta = ifelse(effector == ref_a1, beta, -beta),
         proxy_SNP = ifelse(proxy==0,NA,proxy_SNP),
         r2 = ifelse(proxy==0,NA,r2),
         proxy_effect_allele = ifelse(proxy==0,NA,proxy_effect_allele)) %>% 
  dplyr::select(Tissue:SNP,trait,catalog,effect_allele,proxy_SNP,r2,proxy_effect_allele,beta,se,pval,ancestry,pmid) %>% 
  filter(!trait %in% c("KDEL (Lys-Asp-Glu-Leu) containing 2, isoform CRA_a",
                       "Kunitz-type protease inhibitor 2",
                       "Tumor necrosis factor receptor superfamily member 10B",
                       "Glutathione S-transferase P",
                       "Cation-independent mannose-6-phosphate receptor",
                       "Cathepsin S",
                       "Hepatoma-derived growth factor")) %>% 
  mutate(Protein = factor(Protein, 
                          levels = c("KDELC2","SPINT2","TNFRSF10B",
                                     "GSTP1","IGF2R","CTSS","HDGF"))) %>% 
  arrange(desc(Tissue), Protein)
write.csv(pleio_pheno_summary_raw, file="table s5.csv")

# Table 1: Steiger filtering ----------------------------------------------
harmonised_plasma_MS %>%
  filter(SNP %in% table1_plasma$SNP) %>% 
  steiger_filtering()

# Table 2: Colocalization --------------------------------------------
coloc_CTSS_dat <- read_excel("CTSS.xlsx")
coloc_GSTP1_dat <- read_excel("GSTP1.xlsx")
coloc_HDGF_dat <- read_excel("HDGF.xlsx")
coloc_IGF2R_dat <- read_excel("IGF2R.xlsx")
coloc_KDELC2_dat <- read_excel("KDELC2.xlsx")
coloc_SPINT2_dat <- read_excel("SPINT2.xlsx")
coloc_TNFRSF10B_dat <- read_excel("TNFRSF10B.xlsx")

extract_coloc_outcome_dat <- function(coloc_exposure_dat,
                                      outcome_id = "ebi-a-GCST006085")
{
  coloc_outcome_dat <- 
    extract_outcome_data(snps = ,
                         outcomes = "ebi-a-GCST006085",
                         proxies = F) %>% 
    mutate(chr.outcome = as.numeric(chr),
           pos.outcome = as.numeric(pos),
           outcome = "outcome", 
           id.outcome = "ebi-a-GCST006085")
  
  return(coloc_outcome_dat)
}

coloc_MS_dat <- extract_outcome_data(snps = c(coloc_CTSS_dat$SNP,
                                              coloc_GSTP1_dat$SNP,
                                              coloc_KDELC2_dat$SNP,
                                              coloc_SPINT2_dat$SNP,
                                              coloc_TNFRSF10B_dat$SNP),
                                     outcomes = "ebi-a-GCST006085",
                                     proxies = F) %>% 
  mutate(chr.outcome = as.numeric(chr),
         pos.outcome = as.numeric(pos),
         outcome = "pro cancer", 
         id.outcome = "ebi-a-GCST006085")

#' @description An modified colocalization algorithm
coloc_test_o <- function(exposure_dat,
                         outcome_dat,
                         type_exposure = "quant",
                         col_snp_exposure = "SNP",
                         col_beta_exposure = "beta",
                         col_se_exposure = "se",
                         col_pvalues_exposure = NA,
                         sd_exposure = NA,
                         col_N_exposure = "samplesize",
                         col_MAF_exposure = "maf",
                         type_outcome = "cc",
                         col_snp_outcome = "SNP",
                         col_beta_outcome = "beta.outcome",
                         col_se_outcome = "se.outcome",
                         col_pvalues_outcome = NA,
                         col_N_outcome = NA,
                         col_MAF_outcome = NA,
                         prevalence_outcome = NA)
{
  cols_exposure <- c(col_pvalues_exposure,
                     col_N_exposure,
                     col_MAF_exposure,
                     col_beta_exposure,
                     col_se_exposure,
                     col_snp_exposure)
  cols_exposure <- cols_exposure[!is.na(cols_exposure)]
  
  cols_outcome <- c(col_pvalues_outcome,
                    col_N_outcome,
                    col_MAF_outcome,
                    col_beta_outcome,
                    col_se_outcome,
                    col_snp_outcome)
  cols_outcome <- cols_outcome[!is.na(cols_outcome)]
  
  stopifnot(all(cols_exposure %in% names(exposure_dat)))
  stopifnot(all(cols_outcome %in% names(outcome_dat)))
  
  snp_overlap <- intersect(exposure_dat[[col_snp_exposure]],
                           outcome_dat[[col_snp_outcome]])
  snp_overlap <- unique(snp_overlap)
  
  exposure_dat <- exposure_dat[exposure_dat[[col_snp_exposure]] %in% snp_overlap,]
  outcome_dat <- outcome_dat[outcome_dat[[col_snp_outcome]] %in% snp_overlap,]
  
  exposure_dat <- exposure_dat[order(exposure_dat[[col_snp_exposure]]),]
  outcome_dat <- outcome_dat[order(outcome_dat[[col_snp_outcome]]),]
  
  exposure_list <- list()
  outcome_list <- list()
  
  for (i in 1:8) {
    list_element <- c("pvalues","N","MAF",
                      "beta","varbeta","snps",
                      "type","sdY")[i]
    col_element <- c(col_pvalues_exposure, col_N_exposure, col_MAF_exposure,
                     col_beta_exposure, col_se_exposure, col_snp_exposure,
                     type_exposure, sd_exposure)[i]
    if(!is.na(col_element)){
      if(list_element %in% c("type","sdY"))
      {
        if(list_element=="sdY") col_element <- as.numeric(col_element)
        exposure_list[[list_element]] <- col_element
      }
      else
      {
        if(list_element == "varbeta")
        {
          exposure_list[[list_element]] <- exposure_dat[[col_element]]*exposure_dat[[col_element]]
        }
        else
        {
          exposure_list[[list_element]] <- exposure_dat[[col_element]]
        }
      }
    }
  }
  
  for (j in 1:8) {
    list_element <- c("pvalues","N","MAF",
                      "beta","varbeta","snps",
                      "type","s")[j]
    col_element <- c(col_pvalues_outcome, col_N_outcome, col_MAF_outcome,
                     col_beta_outcome, col_se_outcome, col_snp_outcome,
                     type_outcome, prevalence_outcome)[j]
    if(!is.na(col_element)){
      if(list_element %in% c("type","s"))
      {
        if(list_element=="s") col_element <- as.numeric(col_element)
        outcome_list[[list_element]] <- col_element
      }
      else
      {
        if(list_element == "varbeta")
        {
          outcome_list[[list_element]] <- outcome_dat[[col_element]]*outcome_dat[[col_element]]
        }
        else
        {
          outcome_list[[list_element]] <- outcome_dat[[col_element]]
        }
      }
    }
  }
  
  coloc_res <- suppressWarnings(
    coloc::coloc.abf(exposure_list,outcome_list, p1 = 1e-04, p2 = 1e-04,p12 = 1e-05)
  )
  
  coloc_res$summary
}

coloc_test <- function(exposure_dat,
                       outcome_dat,
                       type_exposure = "quant",
                       col_snp_exposure = "SNP",
                       col_beta_exposure = "beta",
                       col_se_exposure = "se",
                       col_pvalues_exposure = NA,
                       sd_exposure = NA,
                       col_N_exposure = "samplesize",
                       col_MAF_exposure = "maf",
                       type_outcome = "cc",
                       col_snp_outcome = "SNP",
                       col_beta_outcome = "beta.outcome",
                       col_se_outcome = "se.outcome",
                       col_pvalues_outcome = NA,
                       col_N_outcome = NA,
                       col_MAF_outcome = NA,
                       prevalence_outcome = NA)
{
  cols_exposure <- c(col_pvalues_exposure,
                     col_N_exposure,
                     col_MAF_exposure,
                     col_beta_exposure,
                     col_se_exposure,
                     col_snp_exposure)
  cols_exposure <- cols_exposure[!is.na(cols_exposure)]
  
  cols_outcome <- c(col_pvalues_outcome,
                    col_N_outcome,
                    col_MAF_outcome,
                    col_beta_outcome,
                    col_se_outcome,
                    col_snp_outcome)
  cols_outcome <- cols_outcome[!is.na(cols_outcome)]
  
  stopifnot(all(cols_exposure %in% names(exposure_dat)))
  stopifnot(all(cols_outcome %in% names(outcome_dat)))
  
  snp_overlap <- intersect(exposure_dat[[col_snp_exposure]],
                           outcome_dat[[col_snp_outcome]])
  snp_overlap <- unique(snp_overlap)
  
  slice_1 <- function(dat, col_snp, list_snp)
  {
    dat <- dat[dat[[col_snp]] %in% list_snp,]
    names(dat) <- stringr::str_replace(names(dat), col_snp, "SNP")
    library(tidyverse)
    dat <- dat %>% 
      group_by(SNP) %>% 
      slice(1) %>% 
      ungroup() %>% 
      arrange(SNP)
    names(dat) <- stringr::str_replace(names(dat), "SNP", col_snp)
    dat
  }
  
  exposure_dat <- slice_1(exposure_dat, col_snp_exposure, snp_overlap)
  outcome_dat <- slice_1(outcome_dat, col_snp_outcome, snp_overlap)
  
  exposure_list <- list()
  outcome_list <- list()
  
  for (i in 1:8) {
    list_element <- c("pvalues","N","MAF",
                      "beta","varbeta","snp",
                      "type","sdY")[i]
    col_element <- c(col_pvalues_exposure, col_N_exposure, col_MAF_exposure,
                     col_beta_exposure, col_se_exposure, col_snp_exposure,
                     type_exposure, sd_exposure)[i]
    if(!is.na(col_element)){
      if(list_element %in% c("type","sdY"))
      {
        if(list_element=="sdY") col_element <- as.numeric(col_element)
        exposure_list[[list_element]] <- col_element
      }
      else
      {
        if(list_element == "varbeta")
        {
          exposure_list[[list_element]] <- exposure_dat[[col_element]]*exposure_dat[[col_element]]
        }
        else
        {
          exposure_list[[list_element]] <- exposure_dat[[col_element]]
        }
      }
    }
  }
  
  for (j in 1:8) {
    list_element <- c("pvalues","N","MAF",
                      "beta","varbeta","snp",
                      "type","s")[j]
    col_element <- c(col_pvalues_outcome, col_N_outcome, col_MAF_outcome,
                     col_beta_outcome, col_se_outcome, col_snp_outcome,
                     type_outcome, prevalence_outcome)[j]
    if(!is.na(col_element)){
      if(list_element %in% c("type","s"))
      {
        if(list_element=="s") col_element <- as.numeric(col_element)
        outcome_list[[list_element]] <- col_element
      }
      else
      {
        if(list_element == "varbeta")
        {
          outcome_list[[list_element]] <- outcome_dat[[col_element]]*outcome_dat[[col_element]]
        }
        else
        {
          outcome_list[[list_element]] <- outcome_dat[[col_element]]
        }
      }
    }
  }
  
  coloc_res <- suppressWarnings(
    coloc::coloc.abf(exposure_list,outcome_list, p1 = 1e-04, p2 = 1e-04,p12 = 1e-05)
  )
  
  coloc_res$summary
}

coloc_test(exposure_dat = coloc_CTSS_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_GSTP1_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_HDGF_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_IGF2R_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_KDELC2_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_SPINT2_dat,
           outcome_dat = coloc_MS_dat)
coloc_test(exposure_dat = coloc_TNFRSF10B_dat,
           outcome_dat = coloc_MS_dat)

coloc_plot <- function(exposure_dat = coloc_SLAF7_dat,
                       exposure = "SLAF7",
                       col_snp_exposure = "SNP",
                       col_pvalues_exposure = "pval",
                       outcome_dat = coloc_MS_dat,
                       outcome = "PCA",
                       col_snp_outcome = "SNP",
                       col_pvalues_outcome = "pval.outcome",
                       path = tempdir(),
                       combine = FALSE,
                       legend = FALSE)
{
  library(locuscomparer)
  
  snp_overlap <- intersect(exposure_dat[[col_snp_exposure]],
                           outcome_dat[[col_snp_outcome]])
  snp_overlap <- unique(snp_overlap)
  
  exposure_dat <- exposure_dat[exposure_dat[[col_snp_exposure]] %in% snp_overlap,]
  outcome_dat <- outcome_dat[outcome_dat[[col_snp_outcome]] %in% snp_overlap,]
  
  exposure_dat <- exposure_dat[order(exposure_dat[[col_snp_exposure]]),]
  outcome_dat <- outcome_dat[order(outcome_dat[[col_snp_outcome]]),]
  
  exposure_dat <- data.frame(
    rsid = exposure_dat[[col_snp_exposure]],
    pval = exposure_dat[[col_pvalues_exposure]])
  
  outcome_dat <- data.frame(
    rsid = outcome_dat[[col_snp_outcome]],
    pval = outcome_dat[[col_pvalues_outcome]])
  
  write.table(exposure_dat,paste0(path,"/exposure_test.tsv"),sep = "\t",row.names = F,quote = F)
  write.table(outcome_dat,paste0(path,"/outcome_test.tsv"),sep = "\t",row.names = F,quote = F)
  p <- locuscompare(in_fn1 = paste0(path,"/outcome_test.tsv"), 
                    in_fn2 = paste0(path,"/exposure_test.tsv"), 
                    title1 = paste0(outcome," GWAS"),
                    title2 = paste0(exposure," pQTL"),
                    combine = combine,
                    legend = legend)
  p
}


gridExtra::grid.arrange(
  coloc_plot(exposure_dat = coloc_TNFRSF10B_dat, exposure = "TNFRSF10B",combine = F)$locuscompare+ggtitle("(TNFRSF10B)"),
  nrow = 1, ncol = 1)

coloc_plot(exposure_dat = coloc_CTSS_dat, exposure = "CTSS",combine = F)$locuscompare+ggtitle("(A CTSS)")
coloc_plot(exposure_dat = coloc_GSTP1_dat, exposure = "GSTP1",combine = F)$locuscompare+ggtitle("(B GSTP1)")
coloc_plot(exposure_dat = coloc_HDGF_dat, exposure = "HDGF",combine = F)$locuscompare+ggtitle("(C HDGF)")
coloc_plot(exposure_dat = coloc_IGF2R_dat, exposure = "IGF2R",combine = F)$locuscompare+ggtitle("(D IGF2R)")
coloc_plot(exposure_dat = coloc_KDELC2_dat, exposure = "KDELC2",combine = F)$locuscompare+ggtitle("(E KDELC2)")
coloc_plot(exposure_dat = coloc_SPINT2_dat, exposure = "SPINT2",combine = F)$locuscompare+ggtitle("(F SPINT2)")
coloc_plot(exposure_dat = coloc_TNFRSF10B_dat, exposure = "TNFRSF10B",combine = F)$locuscompare+ggtitle("(G TNFRSF10B)"))




